@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
+import os
 import requests
+import tarfile
 import tuxsuite.config
 import pytest
 
@@ -128,3 +130,48 @@ def plan_config(tmp_path, sample_plan_config):
     c = tmp_path / "planv1.yml"
     c.write_text(sample_plan_config)
     return c
+
+
+@pytest.fixture
+def sample_patch():
+    return "example mbox patch"
+
+
+@pytest.fixture
+def sample_patch_file(tmp_path, sample_patch):
+    p = tmp_path / "patch.mbox"
+    p.write_text(sample_patch)
+    return str(p)
+
+
+@pytest.fixture
+def sample_patch_dir(tmp_path, sample_patch):
+    p = tmp_path / "patch.mbox"
+    p.write_text(sample_patch)
+    s = tmp_path / "series"
+    s.write_text("mock series file")
+    return str(tmp_path)
+
+
+@pytest.fixture
+def sample_patch_tgz(tmp_path, sample_patch, sample_patch_dir):
+    p = tmp_path / "patch.mbox"
+    p.write_text(sample_patch)
+    s = tmp_path / "series"
+    s.write_text("mock series file")
+    tar_file = os.path.join(tmp_path, "patch.tgz")
+    with tarfile.open(tar_file, "w:gz") as tar:
+        tar.add(tmp_path, arcname=os.path.sep)
+    return str(tar_file)
+
+
+@pytest.fixture
+def sample_patch_tgz_no_series(tmp_path, sample_patch, sample_patch_dir):
+    p = tmp_path / "patch.mbox"
+    p.write_text(sample_patch)
+    s = tmp_path / "series"
+    os.remove(s)
+    tar_file = os.path.join(tmp_path, "no_series_patch.tgz")
+    with tarfile.open(tar_file, "w:gz") as tar:
+        tar.add(tmp_path, arcname=os.path.sep)
+    return str(tar_file)
